==> ejc-purchasingmanagement-impl-3.0.0-20220718.141214-167-sources.jar: com/ejianc/business/purchasingmanagement/bean/ShippersinvoiceInfoEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运输商开票信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_shippersinvoiceInfo")
public class ShippersinvoiceInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="shippersinvoice_id")
    private Long shippersinvoiceId; // 
    @TableField(value="invoice_code")
    private String invoiceCode; // 发票号码
    @TableField(value="invoice_date")
    private Date invoiceDate; // 发票日期
    @TableField(value="invoice_amount")
    private BigDecimal invoiceAmount; // 发票金额
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="drawer_id")
    private Long drawerId; // 开票人id（默认当前登录人）
    @TableField(value="drawer")
    private String drawer; // 开票人
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中

    @TableField(value="quantity")
    private Long quantity;  //数量


    public Long getQuantity() {
        return quantity;
    }

    public void setQuantity(Long quantity) {
        this.quantity = quantity;
    }



    public Long getShippersinvoiceId() {
        return shippersinvoiceId;
    }

    public void setShippersinvoiceId(Long shippersinvoiceId) {
        this.shippersinvoiceId = shippersinvoiceId;
    }
    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    public Date getInvoiceDate() {
        return invoiceDate;
    }

    public void setInvoiceDate(Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }

    public BigDecimal getInvoiceAmount() {
        return invoiceAmount;
    }

    public void setInvoiceAmount(BigDecimal invoiceAmount) {
        this.invoiceAmount = invoiceAmount;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public Long getDrawerId() {
        return drawerId;
    }

    public void setDrawerId(Long drawerId) {
        this.drawerId = drawerId;
    }
    public String getDrawer() {
        return drawer;
    }

    public void setDrawer(String drawer) {
        this.drawer = drawer;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220903.162409-208-sources.jar: com/ejianc/business/purchasingmanagement/bean/ShippersinvoiceInfoEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运输商开票信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_shippersinvoiceInfo")
public class ShippersinvoiceInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="shippersinvoice_id")
    private Long shippersinvoiceId; // 
    @TableField(value="invoice_code")
    private String invoiceCode; // 发票号码
    @TableField(value="invoice_date")
    private Date invoiceDate; // 发票日期
    @TableField(value="invoice_amount")
    private BigDecimal invoiceAmount; // 发票金额
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="drawer_id")
    private Long drawerId; // 开票人id（默认当前登录人）
    @TableField(value="drawer")
    private String drawer; // 开票人
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中

    @TableField(value="quantity")
    private Long quantity;  //数量
    @TableField(value="annex")
    private String annex; // 附件


    public Long getQuantity() {
        return quantity;
    }

    public void setQuantity(Long quantity) {
        this.quantity = quantity;
    }



    public Long getShippersinvoiceId() {
        return shippersinvoiceId;
    }

    public void setShippersinvoiceId(Long shippersinvoiceId) {
        this.shippersinvoiceId = shippersinvoiceId;
    }
    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    public Date getInvoiceDate() {
        return invoiceDate;
    }

    public void setInvoiceDate(Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }

    public BigDecimal getInvoiceAmount() {
        return invoiceAmount;
    }

    public void setInvoiceAmount(BigDecimal invoiceAmount) {
        this.invoiceAmount = invoiceAmount;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public Long getDrawerId() {
        return drawerId;
    }

    public void setDrawerId(Long drawerId) {
        this.drawerId = drawerId;
    }
    public String getDrawer() {
        return drawer;
    }

    public void setDrawer(String drawer) {
        this.drawer = drawer;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getAnnex() {
        return annex;
    }

    public void setAnnex(String annex) {
        this.annex = annex;
    }
}
